@@ -90,13 +90,14 @@ class Dummy_smtplib(object):
             "SMTP connection not quit")
         self.__class__.existing = None
 
+
 class AppError(Exception):
     pass
 
+
 class TestApp(object):
 
-    # for py.test
-    disabled = True
+    __test__ = False  # Ignore with pytest test collection.
 
     def __init__(self, app, namespace=None, relative_to=None,
                  extra_environ=None, pre_request_hook=None,
@@ -189,8 +190,7 @@ class TestApp(object):
         """
         if extra_environ is None:
             extra_environ = {}
-        # Hide from py.test:
-        __tracebackhide__ = True
+        __tracebackhide__ = True  # Hide from pytest:
         if params:
             if not isinstance(params, (six.binary_type, six.text_type)):
                 params = urlencode(params, doseq=True)
@@ -494,10 +494,10 @@ class CaptureStdout(object):
     def getvalue(self):
         return self.captured.getvalue()
 
+
 class TestResponse(object):
 
-    # for py.test
-    disabled = True
+    __test__ = False  # Ignore with pytest test collection.
 
     """
     Instances of this class are return by `TestApp
@@ -557,7 +557,10 @@ class TestResponse(object):
         forms = self._forms_indexed = {}
         form_texts = []
         started = None
-        for match in self._tag_re.finditer(self.body):
+        body = self.body
+        if not six.PY2:
+            body = body.decode('utf8', 'xmlcharrefreplace')
+        for match in self._tag_re.finditer(body):
             end = match.group(1) == '/'
             tag = match.group(2).lower()
             if tag != 'form':
@@ -565,14 +568,14 @@ class TestResponse(object):
             if end:
                 assert started, (
                     "</form> unexpected at %s" % match.start())
-                form_texts.append(self.body[started:match.end()])
+                form_texts.append(body[started:match.end()])
                 started = None
             else:
                 assert not started, (
                     "Nested form tags at %s" % match.start())
                 started = match.start()
         assert not started, (
-            "Danging form: %r" % self.body[started:])
+            "Dangling form: %r" % body[started:])
         for i, text in enumerate(form_texts):
             form = Form(self, text)
             forms[i] = form
@@ -852,7 +855,7 @@ class TestResponse(object):
                 print("Actual response (has %r)" % no_s, file=sys.stderr)
                 print(self, file=sys.stderr)
                 raise IndexError(
-                    "Body contains string %r" % s)
+                    "Body contains string %r" % no_s)
 
     def __repr__(self):
         body = self.body
@@ -884,10 +887,10 @@ class TestResponse(object):
         url = 'file:' + fn.replace(os.sep, '/')
         webbrowser.open_new(url)
 
+
 class TestRequest(object):
 
-    # for py.test
-    disabled = True
+    __test__ = False  # Ignore with pytest test collection.
 
     """
     Instances of this class are created by `TestApp
@@ -961,8 +964,9 @@ class Form(object):
         in_select = None
         in_textarea = None
         fields = {}
-        for match in self._tag_re.finditer(self.text):
-            end = match.group(1) == '/'
+        text = self.text
+        for match in self._tag_re.finditer(text):
+            end = match.group(1) == b'/'
             tag = match.group(2).lower()
             if tag not in ('input', 'select', 'option', 'textarea',
                            'button'):
@@ -1020,7 +1024,8 @@ class Form(object):
 
     def _parse_action(self):
         self.action = None
-        for match in self._tag_re.finditer(self.text):
+        text = self.text
+        for match in self._tag_re.finditer(text):
             end = match.group(1) == '/'
             tag = match.group(2).lower()
             if tag != 'form':
@@ -1331,8 +1336,7 @@ class TestFileEnvironment(object):
     scripts will be run.
     """
 
-    # for py.test
-    disabled = True
+    __test__ = False  # Ignore with pytest test collection.
 
     def __init__(self, base_path, template_path=None,
                  script_path=None,
@@ -1722,9 +1726,10 @@ def _make_pattern(pat):
     assert 0, (
         "Cannot make callable pattern object out of %r" % pat)
 
+
 def setup_module(module=None):
     """
-    This is used by py.test if it is in the module, so you can
+    This is used by pytest if it is in the module, so you can
     import this directly.
 
     Use like::
