@@ -33,7 +33,7 @@ If there are syntax errors ``TemplateError`` will be raised.
 import re
 import six
 import sys
-import cgi
+from html import escape
 from six.moves.urllib.parse import quote
 from paste.util.looper import looper
 
@@ -318,28 +318,27 @@ def html_quote(value):
     if value is None:
         return ''
     if not isinstance(value, six.string_types):
-        if hasattr(value, '__unicode__'):
+        if six.PY2 and hasattr(value, '__unicode__'):
             value = unicode(value)
         else:
             value = str(value)
-    value = cgi.escape(value, 1)
-    if isinstance(value, unicode):
+    value = escape(value, 1)
+    if six.PY2 and isinstance(value, unicode):
         value = value.encode('ascii', 'xmlcharrefreplace')
     return value
 
 def url(v):
     if not isinstance(v, six.string_types):
-        if hasattr(v, '__unicode__'):
+        if six.PY2 and hasattr(v, '__unicode__'):
             v = unicode(v)
         else:
             v = str(v)
-    if isinstance(v, unicode):
+    if six.PY2 and isinstance(v, unicode):
         v = v.encode('utf8')
     return quote(v)
 
 def attr(**kw):
-    kw = kw.items()
-    kw.sort()
+    kw = sorted(kw.items())
     parts = []
     for name, value in kw:
         if value is None:
